summaryrefslogtreecommitdiff
path: root/Source/cmExportFileGenerator.cxx
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2021-10-08 10:18:58 -0400
committerBrad King <brad.king@kitware.com>2021-10-08 12:17:04 -0400
commitb3248c083f17ee95d4fd0c0397e163a01b096e44 (patch)
tree615e93cca94bffcd9ae869711def9fff7766abf1 /Source/cmExportFileGenerator.cxx
parent0f31463c37dd5cafa27df8fd4a0cb161d18f2f0b (diff)
downloadcmake-b3248c083f17ee95d4fd0c0397e163a01b096e44.tar.gz
export: Increase maximum policy version in exported files to 3.21
The files generatd by `install(EXPORT)` and `export()` commands are known to work with policies as of CMake 3.21, so enable them in sufficiently new CMake versions.
Diffstat (limited to 'Source/cmExportFileGenerator.cxx')
-rw-r--r--Source/cmExportFileGenerator.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/Source/cmExportFileGenerator.cxx b/Source/cmExportFileGenerator.cxx
index 8ca9a66cd1..c0a4cdc338 100644
--- a/Source/cmExportFileGenerator.cxx
+++ b/Source/cmExportFileGenerator.cxx
@@ -924,13 +924,13 @@ void cmExportFileGenerator::GeneratePolicyHeaderCode(std::ostream& os)
// Isolate the file policy level.
// Support CMake versions as far back as 2.6 but also support using NEW
// policy settings for up to CMake 3.20 (this upper limit may be reviewed
// and increased from time to time). This reduces the opportunity for CMake
// warnings when an older export file is later used with newer CMake
// versions.
/* clang-format off */
os << "cmake_policy(PUSH)\n"
- << "cmake_policy(VERSION 2.6...3.20)\n";
+ << "cmake_policy(VERSION 2.6...3.21)\n";
/* clang-format on */
}
@@ -924,13 +924,13 @@ void cmExportFileGenerator::GeneratePolicyHeaderCode(std::ostream& os)
// Isolate the file policy level.
// Support CMake versions as far back as 2.6 but also support using NEW
- // policy settings for up to CMake 3.20 (this upper limit may be reviewed
+ // policy settings for up to CMake 3.21 (this upper limit may be reviewed
// and increased from time to time). This reduces the opportunity for CMake
// warnings when an older export file is later used with newer CMake